% Function to solve the Riccati equation using the transition matrix
% approach
function Pnext = odefcnG_CT(dt,P,A,Q,G)
%%% INPUT
% dt - time step of propagation
% P - initial covariance matrix at time t
% A - Jacobian wrt to low-order moments calculated at current state at time t 
% Q - process covariance matrix at time t
% G - Jacobian wrt to higher-order moments calculated at current state at time t

%%% OUTPUT
% Pnext - propagated covariance matrix P at time t+dt
    nx = length(A);
    Phi = expm([[A G*Q*G'];[zeros(size(A)) -A']]*dt);
    Pnext = (Phi(1:nx,1:nx)*P+Phi(1:nx,nx+1:end))*pinv(Phi(nx+1:end,1:nx)*P+Phi(nx+1:end,nx+1:end));
end
